@@ -158,6 +158,7 @@
 #' \item{family}{the user-provided or default \code{family} argument used to fit the model}
 #' \item{formula}{The model formula provided by the user (not including ESF component)}
 #' \item{slx}{The \code{slx} formula}
+#' \item{C}{The spatial weights matrix, if one was provided by the user.}
 #' \item{re}{A list containing \code{re}, the random effects (varying intercepts) formula if provided, and 
 #'  \code{Data} a data frame with columns \code{id}, the grouping variable, and \code{idx}, the index values assigned to each group.}
 #' \item{priors}{Prior specifications.}
@@ -382,6 +383,7 @@ stan_glm <- function(formula,
     }
     if (!missing(C) && (inherits(C, "matrix") | inherits(C, "Matrix"))) {
         R <- resid(out, summary = FALSE)
+        out$C <- as(C, "dMatrix")
         out$diagnostic["Residual_MC"] <- mean( apply(R, 1, mc, w = C, warn = FALSE, na.rm = TRUE) )
     }        
     return(out)
